# Oh-My-Profiles

# installation 安装

```
pip install OhMyProfiles
```

# Instructions 使用
```

   *******     ****     ****   *******
  **/////**   /**/**   **/**  /**////**
 **     //**  /**//** ** /**  /**   /**
/**      /**  /** //***  /**  /*******
/**      /**  /**  //*   /**  /**////
//**     **   /**   /    /**  /**
 //*******    /**        /**  /**
  ///////     //         //   //

    
Oh My Profiles v0.10

-h              help                    Show help message
-a              add [filename]          Manage my profile
-l              list                    List file to manager
                export                  Export to zip
                import [filename]       Import profile
-r              rm [UUID]               Delete a config
```